import ecs100.*;
import java.awt.Color;
import java.io.*;

/**
 * Allows user to enter a sequence of numbers that is
 * stored to a file.
 */
public class Numbers{
    private PrintStream output;
    private double barX = 0;
    private final double base = 450;

    public void setupGUI(){
        UI.setMouseListener(this::doMouse);
        UI.addButton("Restart", this::doRestart); 
        UI.addButton("Done", this::doDone); 
        UI.addButton("Quit", UI::quit); 
        UI.drawLine(0, this.base, 500, this.base);
    }

    /**
     * Add a number when mouse is released,
     * but only if there is a file to save it to
     */
    public void doMouse(String action, double x, double y) {
        if (action.equals("released") && this.output!=null) {
            double number = this.base - y;
            this.barX = this.barX + 10;
            UI.fillRect(this.barX, y, 5, number);
            UI.println(number);
            this.output.println(number);
        }
    }

    /** Restart the list of numbers and get a new file */
    public void doRestart(){
        UI.clearGraphics();  
        UI.clearText();  
        UI.drawLine(0, this.base, 500, this.base);
        this.barX = 0;
        if (this.output!=null){
            this.output.close();
        }
        try{
            this.output = new PrintStream(UIFileChooser.save());
        } catch(IOException e) { System.out.println("File error: "+e); }
    }

    /** Close off the current file */
    public void doDone(){
	if (this.output!=null){
	    this.output.close();
	    this.output=null;
	}
	UI.clearText();
	UI.println("Saved data to file");
    }

    public static void main(String[] args){
        new Numbers().setupGUI();
    }

}

